@@ -28,11 +28,14 @@ import (
 )
 
 func TestUpdateForCNBImage(t *testing.T) {
-	// metadata with default process type
+	// metadata with default process type `web`
 	md := cnb.BuildMetadata{Processes: []launch.Process{
 		{Type: "web", Command: "webProcess", Args: []string{"webArg1", "webArg2"}},
 		{Type: "diag", Command: "diagProcess"},
 		{Type: "direct", Command: "command", Args: []string{"cmdArg1"}, Direct: true},
+		// Google Buildpacks turns Procfiles into `/bin/bash -c cmdline`
+		{Type: "sh-c", Command: "/bin/sh", Args: []string{"-c", "command arg1 arg2"}, Direct: true},
+		{Type: "bash-c", Command: "/bin/bash", Args: []string{"-c", "command arg1 arg2"}, Direct: true},
 	}}
 	mdMarshalled, _ := json.Marshal(&md)
 	mdJSON := string(mdMarshalled)
@@ -49,6 +52,7 @@ func TestUpdateForCNBImage(t *testing.T) {
 		input       imageConfiguration
 		shouldErr   bool
 		expected    v1.Container
+		config      ContainerDebugConfiguration
 	}{
 		{
 			description: "error when missing build.metadata",
@@ -65,48 +69,84 @@ func TestUpdateForCNBImage(t *testing.T) {
 			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, arguments: []string{"--", "web", "arg1", "arg2"}, labels: map[string]string{"io.buildpacks.build.metadata": mdJSON}},
 			shouldErr:   false,
 			expected:    v1.Container{Args: []string{"--", "web", "arg1", "arg2"}},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
 		},
 		{
 			description: "defaults to web process when no process type",
 			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, labels: map[string]string{"io.buildpacks.build.metadata": mdJSON}},
 			shouldErr:   false,
 			expected:    v1.Container{Args: []string{"webProcess", "webArg1", "webArg2"}},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
 		},
 		{
 			description: "resolves to default 'web' process",
 			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, labels: map[string]string{"io.buildpacks.build.metadata": mdJSON}},
 			shouldErr:   false,
 			expected:    v1.Container{Args: []string{"webProcess", "webArg1", "webArg2"}},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
 		},
 		{
 			description: "CNB_PROCESS_TYPE=web",
 			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, env: map[string]string{"CNB_PROCESS_TYPE": "web"}, labels: map[string]string{"io.buildpacks.build.metadata": mdJSON}},
 			shouldErr:   false,
 			expected:    v1.Container{Args: []string{"webProcess", "webArg1", "webArg2"}},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
 		},
 		{
 			description: "CNB_PROCESS_TYPE=diag",
 			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, env: map[string]string{"CNB_PROCESS_TYPE": "diag"}, labels: map[string]string{"io.buildpacks.build.metadata": mdJSON}},
 			shouldErr:   false,
 			expected:    v1.Container{Args: []string{"diagProcess"}},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
 		},
 		{
 			description: "CNB_PROCESS_TYPE=direct",
 			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, env: map[string]string{"CNB_PROCESS_TYPE": "direct"}, labels: map[string]string{"io.buildpacks.build.metadata": mdJSON}},
 			shouldErr:   false,
 			expected:    v1.Container{Args: []string{"--", "command", "cmdArg1"}},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
 		},
 		{
 			description: "script command-line",
 			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, arguments: []string{"python main.py"}, labels: map[string]string{"io.buildpacks.build.metadata": mdJSON}},
 			shouldErr:   false,
 			expected:    v1.Container{Args: []string{"python main.py"}},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
 		},
 		{
 			description: "no process and no args",
 			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, labels: map[string]string{"io.buildpacks.build.metadata": mdndJSON}},
 			shouldErr:   false,
 			expected:    v1.Container{},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
+		},
+		{
+			description: "launcher ignores image's working dir",
+			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, labels: map[string]string{"io.buildpacks.build.metadata": mdndJSON}, workingDir: "/workdir"},
+			shouldErr:   false,
+			expected:    v1.Container{},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
+		},
+		{
+			description: "CNB_APP_DIR used if set",
+			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, labels: map[string]string{"io.buildpacks.build.metadata": mdndJSON}, env: map[string]string{"CNB_APP_DIR": "/appDir"}, workingDir: "/workdir"},
+			shouldErr:   false,
+			expected:    v1.Container{},
+			config:      ContainerDebugConfiguration{WorkingDir: "/appDir"},
+		},
+		{
+			description: "CNB_PROCESS_TYPE=sh-c ()Procfile-style)",
+			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, env: map[string]string{"CNB_PROCESS_TYPE": "sh-c"}, labels: map[string]string{"io.buildpacks.build.metadata": mdJSON}},
+			shouldErr:   false,
+			expected:    v1.Container{Args: []string{"command arg1 arg2"}},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
+		},
+		{
+			description: "CNB_PROCESS_TYPE=bash-c ()Procfile-style)",
+			input:       imageConfiguration{entrypoint: []string{"/cnb/lifecycle/launcher"}, env: map[string]string{"CNB_PROCESS_TYPE": "sh-c"}, labels: map[string]string{"io.buildpacks.build.metadata": mdJSON}},
+			shouldErr:   false,
+			expected:    v1.Container{Args: []string{"command arg1 arg2"}},
+			config:      ContainerDebugConfiguration{WorkingDir: "/workspace"},
 		},
 	}
 	for _, test := range tests {
@@ -118,14 +158,15 @@ func TestUpdateForCNBImage(t *testing.T) {
 				return ContainerDebugConfiguration{}, "", nil
 			}
 			copy := v1.Container{}
-			_, _, err := updateForCNBImage(&copy, test.input, argsChangedTransform)
+			c, _, err := updateForCNBImage(&copy, test.input, argsChangedTransform)
 			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.expected, copy)
+			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.config, c)
 		})
 
 		// Test that when the arguments are left unchanged, that the container is unchanged
 		testutil.Run(t, test.description+" (args unchanged)", func(t *testutil.T) {
 			argsUnchangedTransform := func(c *v1.Container, ic imageConfiguration) (ContainerDebugConfiguration, string, error) {
-				return ContainerDebugConfiguration{}, "", nil
+				return ContainerDebugConfiguration{WorkingDir: ic.workingDir}, "", nil
 			}
 
 			copy := v1.Container{}
