@@ -216,6 +216,16 @@ FROM stage
 ADD ./file /etc/file
 `
 
+const invalidFrom = `
+FROM
+COPY . /
+`
+
+const fromV1Manifest = `
+FROM library/ruby:2.3.0
+ADD ./file /etc/file
+`
+
 type fakeImageFetcher struct{}
 
 func (f *fakeImageFetcher) fetch(image string, _ Config) (*v1.ConfigFile, error) {
@@ -230,6 +240,8 @@ func (f *fakeImageFetcher) fetch(image string, _ Config) (*v1.ConfigFile, error)
 				},
 			},
 		}, nil
+	case "library/ruby:2.3.0":
+		return nil, fmt.Errorf("retrieving image \"library/ruby:2.3.0\": unsupported MediaType: \"application/vnd.docker.distribution.manifest.v1+prettyjws\", see https://github.com/google/go-containerregistry/issues/377")
 	}
 
 	return nil, fmt.Errorf("no image found for %s", image)
@@ -530,6 +542,18 @@ func TestGetDependencies(t *testing.T) {
 			ignoreFilename: "Dockerfile.dockerignore",
 			expected:       []string{".dot", "Dockerfile", "Dockerfile.dockerignore", "file", "server.go", "test.conf", "worker.go"},
 		},
+		{
+			description: "invalid dockerfile",
+			dockerfile:  invalidFrom,
+			workspace:   ".",
+			shouldErr:   true,
+		},
+		{
+			description: "old manifest version - watch local file dependency.",
+			dockerfile:  fromV1Manifest,
+			workspace:   ".",
+			expected:    []string{"Dockerfile", "file"},
+		},
 	}
 
 	for _, test := range tests {
@@ -629,3 +653,63 @@ func checkSameFile(t *testutil.T, expected, result string) {
 		t.Errorf("returned wrong file\n   got: %s\nwanted: %s", result, expected)
 	}
 }
+
+func TestGetDependenciesCached(t *testing.T) {
+	imageFetcher := fakeImageFetcher{}
+	tests := []struct {
+		description     string
+		retrieveImgMock func(_ string, _ Config) (*v1.ConfigFile, error)
+		dependencyCache map[string]interface{}
+		expected        []string
+		shouldErr       bool
+	}{
+		{
+			description:     "with no cached results getDependencies will retrieve image",
+			retrieveImgMock: imageFetcher.fetch,
+			dependencyCache: map[string]interface{}{},
+			expected:        []string{"Dockerfile", "server.go"},
+		},
+		{
+			description: "with cached results getDependencies should read from cache",
+			retrieveImgMock: func(_ string, _ Config) (*v1.ConfigFile, error) {
+				return nil, fmt.Errorf("unexpected call")
+			},
+			dependencyCache: map[string]interface{}{"Dockerfile": []string{"random.go"}},
+			expected:        []string{"random.go"},
+		},
+		{
+			description: "with cached results is error getDependencies should read from cache",
+			retrieveImgMock: func(_ string, _ Config) (*v1.ConfigFile, error) {
+				return &v1.ConfigFile{}, nil
+			},
+			dependencyCache: map[string]interface{}{"Dockerfile": fmt.Errorf("remote manifest fetch")},
+			shouldErr:       true,
+		},
+		{
+			description:     "with cached results for dockerfile in another app",
+			retrieveImgMock: imageFetcher.fetch,
+			dependencyCache: map[string]interface{}{
+				filepath.Join("app", "Dockerfile"): []string{"random.go"}},
+			expected: []string{"Dockerfile", "server.go"},
+		},
+	}
+
+	for _, test := range tests {
+		testutil.Run(t, test.description, func(t *testutil.T) {
+			t.Override(&RetrieveImage, test.retrieveImgMock)
+			t.Override(&util.OSEnviron, func() []string { return []string{} })
+			t.Override(&dependencyCache, util.NewSyncStore())
+
+			tmpDir := t.NewTempDir().Touch("server.go", "random.go")
+			tmpDir.Write("Dockerfile", copyServerGo)
+
+			for k, v := range test.dependencyCache {
+				dependencyCache.Exec(tmpDir.Path(k), func() interface{} {
+					return v
+				})
+			}
+			deps, err := GetDependencies(context.Background(), tmpDir.Root(), "Dockerfile", map[string]*string{}, nil)
+			t.CheckErrorAndDeepEqual(test.shouldErr, err, test.expected, deps)
+		})
+	}
+}
