@@ -191,8 +191,8 @@ func TestBuild(t *testing.T) {
 	for _, test := range tests {
 		testutil.Run(t, test.description, func(t *testutil.T) {
 			t.Override(&DefaultAuthHelper, testAuthHelper{})
-			t.Override(&EvalBuildArgs, func(mode config.RunMode, workspace string, a *latest.DockerArtifact, extra map[string]*string) (map[string]*string, error) {
-				return util.EvaluateEnvTemplateMap(a.BuildArgs)
+			t.Override(&EvalBuildArgs, func(_ config.RunMode, _ string, _ string, args map[string]*string, _ map[string]*string) (map[string]*string, error) {
+				return util.EvaluateEnvTemplateMap(args)
 			})
 			t.SetEnvs(test.env)
 
@@ -354,6 +354,13 @@ func TestGetBuildArgs(t *testing.T) {
 			},
 			want: []string{"--secret", "id=mysecret,src=foo.src,dst=foo.dst"},
 		},
+		{
+			description: "ssh with no source",
+			artifact: &latest.DockerArtifact{
+				SSH: "default",
+			},
+			want: []string{"--ssh", "default"},
+		},
 		{
 			description: "all",
 			artifact: &latest.DockerArtifact{
