@@ -20,11 +20,13 @@ import (
 	"context"
 	"fmt"
 
+	"github.com/sirupsen/logrus"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	kubernetesclient "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/client"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
+	schemautil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 )
 
@@ -45,6 +47,24 @@ var (
 
 // NewResourceForwarder returns a struct that tracks and port-forwards services as they are created and modified
 func NewResourceForwarder(entryManager *EntryManager, namespaces []string, label string, userDefinedResources []*latest.PortForwardResource) *ResourceForwarder {
+	if len(namespaces) == 1 {
+		for _, pf := range userDefinedResources {
+			if pf.Namespace == "" {
+				pf.Namespace = namespaces[0]
+			}
+		}
+	} else {
+		var validResources []*latest.PortForwardResource
+		for _, pf := range userDefinedResources {
+			if pf.Namespace != "" {
+				validResources = append(validResources, pf)
+			} else {
+				logrus.Warnf("Skipping the port forwarding resource %s/%s because namespace is not specified", pf.Type, pf.Name)
+			}
+		}
+		userDefinedResources = validResources
+	}
+
 	return &ResourceForwarder{
 		entryManager:         entryManager,
 		namespaces:           namespaces,
@@ -122,7 +142,7 @@ func retrieveServiceResources(label string, namespaces []string) ([]*latest.Port
 					Type:      constants.Service,
 					Name:      s.Name,
 					Namespace: s.Namespace,
-					Port:      int(p.Port),
+					Port:      schemautil.FromInt(int(p.Port)),
 					Address:   constants.DefaultPortForwardAddress,
 					LocalPort: int(p.Port),
 				})
