@@ -22,7 +22,6 @@ import (
 	"time"
 
 	"github.com/sirupsen/logrus"
-	"k8s.io/apimachinery/pkg/labels"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build/tag"
@@ -51,10 +50,6 @@ type withTimings struct {
 	cacheArtifacts bool
 }
 
-func (w withTimings) Labels() map[string]string {
-	return labels.Merge(w.Builder.Labels(), w.Deployer.Labels())
-}
-
 func (w withTimings) Build(ctx context.Context, out io.Writer, tags tag.ImageTags, artifacts []*latest.Artifact) ([]build.Artifact, error) {
 	if len(artifacts) == 0 && w.cacheArtifacts {
 		return nil, nil
@@ -82,17 +77,17 @@ func (w withTimings) Test(ctx context.Context, out io.Writer, builds []build.Art
 	return nil
 }
 
-func (w withTimings) Deploy(ctx context.Context, out io.Writer, builds []build.Artifact, labellers []deploy.Labeller) *deploy.Result {
+func (w withTimings) Deploy(ctx context.Context, out io.Writer, builds []build.Artifact) ([]string, error) {
 	start := time.Now()
 	color.Default.Fprintln(out, "Starting deploy...")
 
-	dr := w.Deployer.Deploy(ctx, out, builds, labellers)
-	if err := dr.GetError(); err != nil {
-		return dr
+	ns, err := w.Deployer.Deploy(ctx, out, builds)
+	if err != nil {
+		return nil, err
 	}
 
 	logrus.Infoln("Deploy complete in", time.Since(start))
-	return dr
+	return ns, err
 }
 
 func (w withTimings) Cleanup(ctx context.Context, out io.Writer) error {
