@@ -27,6 +27,7 @@ import (
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/constants"
 	kubectx "github.com/GoogleContainerTools/skaffold/pkg/skaffold/kubernetes/context"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/latest"
+	schemautil "github.com/GoogleContainerTools/skaffold/pkg/skaffold/schema/util"
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/util"
 )
 
@@ -98,7 +99,6 @@ func Set(c *latest.SkaffoldConfig) error {
 	}
 
 	for _, pf := range c.PortForward {
-		setDefaultPortForwardNamespace(pf)
 		setDefaultLocalPort(pf)
 		setDefaultAddress(pf)
 	}
@@ -357,18 +357,9 @@ func currentNamespace() (string, error) {
 
 func setDefaultLocalPort(pf *latest.PortForwardResource) {
 	if pf.LocalPort == 0 {
-		pf.LocalPort = pf.Port
-	}
-}
-
-func setDefaultPortForwardNamespace(pf *latest.PortForwardResource) {
-	if pf.Namespace == "" {
-		ns, err := currentNamespace()
-		if err != nil {
-			pf.Namespace = constants.DefaultPortForwardNamespace
-			return
+		if pf.Port.Type == schemautil.Int {
+			pf.LocalPort = pf.Port.IntVal
 		}
-		pf.Namespace = ns
 	}
 }
 
