@@ -36,7 +36,7 @@ const (
 )
 
 var (
-	ignoredSamples = []string{"structureTest.yaml", "build.sh", "globalConfig.yaml"}
+	ignoredSamples = []string{"structureTest.yaml", "build.sh", "globalConfig.yaml", "Dockerfile.app", "Dockerfile.base"}
 )
 
 // Test that every example can be parsed and produces a valid
@@ -74,15 +74,7 @@ func TestParseSamples(t *testing.T) {
 }
 
 func checkSkaffoldConfig(t *testutil.T, yaml []byte) {
-	root := t.NewTempDir()
-	configFile := root.Path("skaffold.yaml")
-	root.Write("skaffold.yaml", string(yaml))
-	// create workspace directories referenced in these samples
-	for _, d := range []string{"app", "node", "python", "leeroy-web", "leeroy-app", "backend", "base-service", "world-service"} {
-		root.Mkdir(d)
-	}
-	root.Chdir()
-
+	configFile := t.TempFile("skaffold.yaml", yaml)
 	cfg, err := ParseConfigAndUpgrade(configFile, latest.Version)
 	t.CheckNoError(err)
 
