@@ -19,6 +19,7 @@ package validation
 import (
 	"fmt"
 	"reflect"
+	"regexp"
 	"strings"
 
 	"github.com/GoogleContainerTools/skaffold/pkg/skaffold/build/misc"
@@ -30,13 +31,15 @@ import (
 
 var (
 	// for testing
-	validateYamltags = yamltags.ValidateStruct
+	validateYamltags       = yamltags.ValidateStruct
+	dependencyAliasPattern = regexp.MustCompile(`^[a-zA-Z_][a-zA-Z0-9_]*$`)
 )
 
 // Process checks if the Skaffold pipeline is valid and returns all encountered errors as a concatenated string
 func Process(config *latest.SkaffoldConfig) error {
 	errs := visitStructs(config, validateYamltags)
 	errs = append(errs, validateImageNames(config.Build.Artifacts)...)
+	errs = append(errs, validateArtifactDependencies(config.Build.Artifacts)...)
 	errs = append(errs, validateDockerNetworkMode(config.Build.Artifacts)...)
 	errs = append(errs, validateCustomDependencies(config.Build.Artifacts)...)
 	errs = append(errs, validateSyncRules(config.Build.Artifacts)...)
@@ -44,6 +47,7 @@ func Process(config *latest.SkaffoldConfig) error {
 	errs = append(errs, validateJibPluginTypes(config.Build.Artifacts)...)
 	errs = append(errs, validateLogPrefix(config.Deploy.Logs)...)
 	errs = append(errs, validateArtifactTypes(config.Build)...)
+	errs = append(errs, validateTaggingPolicy(config.Build)...)
 
 	if len(errs) == 0 {
 		return nil
@@ -56,6 +60,17 @@ func Process(config *latest.SkaffoldConfig) error {
 	return fmt.Errorf(strings.Join(messages, " | "))
 }
 
+// validateTaggingPolicy checks that the tagging policy is valid in combination with other options.
+func validateTaggingPolicy(bc latest.BuildConfig) (errs []error) {
+	if bc.LocalBuild != nil {
+		// sha256 just uses `latest` tag, so tryImportMissing will virtually always succeed (#4889)
+		if bc.LocalBuild.TryImportMissing && bc.TagPolicy.ShaTagger != nil {
+			errs = append(errs, fmt.Errorf("tagging policy 'sha256' can not be used when 'tryImportMissing' is enabled"))
+		}
+	}
+	return
+}
+
 // validateImageNames makes sure the artifact image names are valid base names,
 // without tags nor digests.
 func validateImageNames(artifacts []*latest.Artifact) (errs []error) {
@@ -77,6 +92,93 @@ func validateImageNames(artifacts []*latest.Artifact) (errs []error) {
 	return
 }
 
+func validateArtifactDependencies(artifacts []*latest.Artifact) (errs []error) {
+	errs = append(errs, validateUniqueDependencyAliases(artifacts)...)
+	errs = append(errs, validateAcyclicDependencies(artifacts)...)
+	errs = append(errs, validateValidDependencyAliases(artifacts)...)
+	return
+}
+
+// validateAcyclicDependencies makes sure all artifact dependencies are found and don't have cyclic references
+func validateAcyclicDependencies(artifacts []*latest.Artifact) (errs []error) {
+	m := make(map[string]*latest.Artifact)
+	for _, artifact := range artifacts {
+		m[artifact.ImageName] = artifact
+	}
+	visited := make(map[string]bool)
+	for _, artifact := range artifacts {
+		if err := dfs(artifact, visited, make(map[string]bool), m); err != nil {
+			errs = append(errs, err)
+			return
+		}
+	}
+	return
+}
+
+// dfs runs a Depth First Search algorithm for cycle detection in a directed graph
+func dfs(artifact *latest.Artifact, visited, marked map[string]bool, artifacts map[string]*latest.Artifact) error {
+	if marked[artifact.ImageName] {
+		return fmt.Errorf("cycle detected in build dependencies involving %q", artifact.ImageName)
+	}
+	marked[artifact.ImageName] = true
+	defer func() {
+		marked[artifact.ImageName] = false
+	}()
+	if visited[artifact.ImageName] {
+		return nil
+	}
+	visited[artifact.ImageName] = true
+
+	for _, dep := range artifact.Dependencies {
+		d, found := artifacts[dep.ImageName]
+		if !found {
+			return fmt.Errorf("unknown build dependency %q for artifact %q", dep.ImageName, artifact.ImageName)
+		}
+		if err := dfs(d, visited, marked, artifacts); err != nil {
+			return err
+		}
+	}
+	return nil
+}
+
+// validateValidDependencyAliases makes sure that artifact dependency aliases are valid.
+// docker and custom builders require aliases match [a-zA-Z_][a-zA-Z0-9_]* pattern
+func validateValidDependencyAliases(artifacts []*latest.Artifact) (errs []error) {
+	for _, a := range artifacts {
+		if a.DockerArtifact == nil && a.CustomArtifact == nil {
+			continue
+		}
+		for _, d := range a.Dependencies {
+			if !dependencyAliasPattern.MatchString(d.Alias) {
+				errs = append(errs, fmt.Errorf("invalid build dependency for artifact %q: alias %q doesn't match required pattern %q", a.ImageName, d.Alias, dependencyAliasPattern.String()))
+			}
+		}
+	}
+	return
+}
+
+// validateUniqueDependencyAliases makes sure that artifact dependency aliases are unique for each artifact
+func validateUniqueDependencyAliases(artifacts []*latest.Artifact) (errs []error) {
+	type State int
+	var (
+		unseen   State = 0
+		seen     State = 1
+		recorded State = 2
+	)
+	for _, a := range artifacts {
+		aliasMap := make(map[string]State)
+		for _, d := range a.Dependencies {
+			if aliasMap[d.Alias] == seen {
+				errs = append(errs, fmt.Errorf("invalid build dependency for artifact %q: alias %q repeated", a.ImageName, d.Alias))
+				aliasMap[d.Alias] = recorded
+			} else if aliasMap[d.Alias] == unseen {
+				aliasMap[d.Alias] = seen
+			}
+		}
+	}
+	return
+}
+
 // validateDockerNetworkMode makes sure that networkMode is one of `bridge`, `none`, or `host` if set.
 func validateDockerNetworkMode(artifacts []*latest.Artifact) (errs []error) {
 	for _, a := range artifacts {
