@@ -35,6 +35,8 @@ import (
 	"github.com/GoogleContainerTools/skaffold/proto"
 )
 
+const maxTryListen = 10
+
 var (
 	srv *server
 
@@ -91,33 +93,18 @@ func SetAutoSyncCallback(callback func(bool)) {
 // It returns a shutdown callback for tearing down the grpc server,
 // which the runner is responsible for calling.
 func Initialize(opts config.SkaffoldOptions) (func() error, error) {
-	if !opts.EnableRPC {
+	if !opts.EnableRPC || opts.RPCPort == -1 {
 		return func() error { return nil }, nil
 	}
 
 	var usedPorts util.PortSet
 
-	originalRPCPort := opts.RPCPort
-	if originalRPCPort == -1 {
-		return func() error { return nil }, nil
-	}
-	rpcPort := util.GetAvailablePort(util.Loopback, originalRPCPort, &usedPorts)
-	if rpcPort != originalRPCPort {
-		logrus.Warnf("port %d for gRPC server already in use: using %d instead", originalRPCPort, rpcPort)
-	}
-	usedPorts.Set(rpcPort)
-	grpcCallback, err := newGRPCServer(rpcPort)
+	grpcCallback, rpcPort, err := newGRPCServer(opts.RPCPort, &usedPorts)
 	if err != nil {
 		return grpcCallback, fmt.Errorf("starting gRPC server: %w", err)
 	}
 
-	originalHTTPPort := opts.RPCHTTPPort
-	httpPort := util.GetAvailablePort(util.Loopback, originalHTTPPort, &usedPorts)
-	if httpPort != originalHTTPPort {
-		logrus.Warnf("port %d for gRPC HTTP server already in use: using %d instead", originalHTTPPort, httpPort)
-	}
-
-	httpCallback, err := newHTTPServer(httpPort, rpcPort)
+	httpCallback, err := newHTTPServer(opts.RPCHTTPPort, rpcPort, &usedPorts)
 	callback := func() error {
 		httpErr := httpCallback()
 		grpcErr := grpcCallback()
@@ -137,12 +124,17 @@ func Initialize(opts config.SkaffoldOptions) (func() error, error) {
 	return callback, nil
 }
 
-func newGRPCServer(port int) (func() error, error) {
-	l, err := net.Listen("tcp", fmt.Sprintf("%s:%d", util.Loopback, port))
+func newGRPCServer(preferredPort int, usedPorts *util.PortSet) (func() error, int, error) {
+	l, port, err := listenOnAvailablePort(preferredPort, usedPorts)
 	if err != nil {
-		return func() error { return nil }, fmt.Errorf("creating listener: %w", err)
+		return func() error { return nil }, 0, fmt.Errorf("creating listener: %w", err)
+	}
+
+	if port != preferredPort {
+		logrus.Warnf("starting gRPC server on port %d. (%d is already in use)", port, preferredPort)
+	} else {
+		logrus.Infof("starting gRPC server on port %d", port)
 	}
-	logrus.Infof("starting gRPC server on port %d", port)
 
 	s := grpc.NewServer()
 	srv = &server{
@@ -176,10 +168,10 @@ func newGRPCServer(port int) (func() error, error) {
 				return l.Close()
 			}
 		}
-	}, nil
+	}, port, nil
 }
 
-func newHTTPServer(port, proxyPort int) (func() error, error) {
+func newHTTPServer(preferredPort, proxyPort int, usedPorts *util.PortSet) (func() error, error) {
 	mux := runtime.NewServeMux(runtime.WithProtoErrorHandler(errorHandler))
 	opts := []grpc.DialOption{grpc.WithInsecure()}
 	err := proto.RegisterSkaffoldServiceHandlerFromEndpoint(context.Background(), mux, fmt.Sprintf("%s:%d", util.Loopback, proxyPort), opts)
@@ -187,11 +179,16 @@ func newHTTPServer(port, proxyPort int) (func() error, error) {
 		return func() error { return nil }, err
 	}
 
-	l, err := net.Listen("tcp", fmt.Sprintf("%s:%d", util.Loopback, port))
+	l, port, err := listenOnAvailablePort(preferredPort, usedPorts)
 	if err != nil {
 		return func() error { return nil }, fmt.Errorf("creating listener: %w", err)
 	}
-	logrus.Infof("starting gRPC HTTP server on port %d", port)
+
+	if port != preferredPort {
+		logrus.Warnf("starting gRPC HTTP server on port %d. (%d is already in use)", port, preferredPort)
+	} else {
+		logrus.Infof("starting gRPC HTTP server on port %d", port)
+	}
 
 	server := &http.Server{
 		Handler: mux,
@@ -220,3 +217,21 @@ func errorHandler(ctx context.Context, _ *runtime.ServeMux, marshaler runtime.Ma
 		writer.Write([]byte(`{"error": "failed to marshal error message"}`))
 	}
 }
+
+func listenOnAvailablePort(preferredPort int, usedPorts *util.PortSet) (net.Listener, int, error) {
+	for try := 1; ; try++ {
+		port := util.GetAvailablePort(util.Loopback, preferredPort, usedPorts)
+
+		l, err := net.Listen("tcp", fmt.Sprintf("%s:%d", util.Loopback, port))
+		if err != nil {
+			if try >= maxTryListen {
+				return nil, 0, err
+			}
+
+			time.Sleep(1 * time.Second)
+			continue
+		}
+
+		return l, port, nil
+	}
+}
